@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2016-06-02'; # DATE
-our $VERSION = '0.30'; # VERSION
+our $DATE = '2016-07-13'; # DATE
+our $VERSION = '0.31'; # VERSION
 
 use 5.010001;
 use strict;
@@ -40,6 +40,20 @@ our %common_args = (
         req     => 1,
         tags    => ['common'],
     },
+    # 2016-07-13 - for a few months now, PAUSE has been giving random 500 errors
+    # when uploading. i'm defaulting to a retries=3
+    retries => {
+        summary => 'Number of retries when received 5xx HTTP error from server',
+        schema  => 'int*',
+        default => 2,
+        tags    => ['common'],
+    },
+    retry_delay => {
+        summary => 'How long to wait before retrying',
+        schema  => 'duration*',
+        default => "3s",
+        tags    => ['common'],
+    },
 );
 
 our %detail_arg = (
@@ -137,7 +151,20 @@ sub _request {
         @{ $args{post_data} });
     $req->authorization_basic($args{username}, $args{password});
 
-    $ua->request($req);
+    my $tries = 0;
+    my $resp;
+  RETRY:
+    while (1) {
+        $resp = $ua->request($req);
+        if ($resp->code =~ /^[5]/ && $args{retries} >= ++$tries) {
+            $log->warnf("Got error %s (%s) from server, retrying (%d/%d) ...",
+                        $resp->code, $resp->message, $tries, $args{retries});
+            sleep $args{retry_delay};
+            next;
+        }
+        last;
+    }
+    $resp;
 }
 
 sub _htres2envres {
@@ -312,6 +339,7 @@ sub upload_files {
 # old name, deprecated
 {
     no strict 'refs';
+    no warnings 'once';
     *upload_file = \&upload_files;
     $SPEC{upload_file} = { %{ $SPEC{upload_files} } }; # shallow clone
     $SPEC{upload_file}{'x.no_index'} = 1;
@@ -402,6 +430,8 @@ sub list_files {
     if ($args{detail}) {
         $resmeta{'table.fields'} =
             [qw/name size mtime is_scheduled_for_deletion deletion_time/];
+        $resmeta{'table.field_formats'} =
+            [undef, undef, 'iso8601_datetime', undef, 'iso8601_date'];
     }
     [200, "OK", \@files, \%resmeta];
 }
@@ -863,7 +893,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.30 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2016-06-02.
+This document describes version 0.31 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2016-07-13.
 
 =head1 SYNOPSIS
 
@@ -904,6 +934,14 @@ PAUSE password.
 
 Protect some files/wildcard patterns from delete/cleanup.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<username>* => I<str>
 
 PAUSE ID.
@@ -972,6 +1010,14 @@ PAUSE password.
 
 Protect some files/wildcard patterns from delete/cleanup.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<username>* => I<str>
 
 PAUSE ID.
@@ -1034,6 +1080,14 @@ Dev versions will be skipped.
 
 PAUSE password.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<username>* => I<str>
 
 PAUSE ID.
@@ -1078,6 +1132,14 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<username>* => I<str>
 
 PAUSE ID.
@@ -1118,6 +1180,14 @@ Module names/wildcard patterns.
 
 PAUSE password.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<type> => I<str>
 
 Only list modules matching certain type.
@@ -1161,6 +1231,14 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<username>* => I<str>
 
 PAUSE ID.
@@ -1214,6 +1292,14 @@ File names/wildcard patterns.
 
 PAUSE password.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<username>* => I<str>
 
 PAUSE ID.
@@ -1292,6 +1378,14 @@ at once, you set this option to 2-3 minutes (120-180 seconds).
 
 PAUSE password.
 
+=item * B<retries> => I<int> (default: 2)
+
+Number of retries when received 5xx HTTP error from server.
+
+=item * B<retry_delay> => I<duration> (default: "3s")
+
+How long to wait before retrying.
+
 =item * B<subdir> => I<str> (default: "")
 
 Subdirectory to put the file(s) into.
